==> gimp-0.99.22.tar.bz2: gimp-0.99.22/app/menus.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef __MENUS_H__
#define __MENUS_H__


#include "gtk/gtk.h"


void menus_get_toolbox_menubar (GtkWidget           **menubar,
				GtkAcceleratorTable **table);
void menus_get_image_menu      (GtkWidget           **menu,
				GtkAcceleratorTable **table);
void menus_get_load_menu       (GtkWidget           **menu,
				GtkAcceleratorTable **table);
void menus_get_save_menu       (GtkWidget           **menu,
				GtkAcceleratorTable **table);
void menus_create              (GtkMenuEntry         *entries,
				int                   nmenu_entries);
void menus_set_sensitive       (char                 *path,
				int                   sensitive);
void menus_set_state           (char                 *path,
				int                   state);
void menus_add_path            (char                 *path,
				char                 *accelerator);
void menus_destroy             (char                 *path);
void menus_quit                (void);


#endif /* MENUS_H */

==> gimp-1.1.3.tar.bz2: gimp-1.1.3/app/menus.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifndef __MENUS_H__
#define __MENUS_H__


#include "gtk/gtk.h"


void menus_get_toolbox_menubar (GtkWidget           **menubar,
				GtkAccelGroup	    **accel_group);
void menus_get_image_menu      (GtkWidget           **menu,
				GtkAccelGroup	    **accel_group);
void menus_get_load_menu       (GtkWidget           **menu,
				GtkAccelGroup	    **accel_group);
void menus_get_save_menu       (GtkWidget           **menu,
				GtkAccelGroup	    **accel_group);
void menus_create              (GtkMenuEntry         *entries,
				int                   nmenu_entries);
void menus_set_sensitive       (char                 *path,
				int                   sensitive);
void menus_set_state           (char                 *path,
				int                   state);
void menus_destroy             (char                 *path);
void menus_quit                (void);
void menus_last_opened_add     (gchar                *filename);


#endif /* MENUS_H */
